@@ -231,6 +231,7 @@ if ($this->GetPreference('allow_add',1) == 1) {
    $this->smarty->assign('standard_title', $this->GetPreference('standard_title','1'));
    $this->smarty->assign('dublin_title', $this->GetPreference('dublin_title','0'));
    $this->smarty->assign('opengraph_title', $this->GetPreference('opengraph_title','0'));
+   $this->smarty->assign('tweetme_title', $this->GetPreference('tweetme_title','0'));
    $this->smarty->assign('touchicon_title', $this->GetPreference('touchicon_title','0'));
    $this->smarty->assign('fullscreen_title', $this->GetPreference('fullscreen_title','-1'));
    $this->smarty->assign('statusbar_title', $this->GetPreference('statusbar_title','-1'));
@@ -244,14 +245,21 @@ if ($this->GetPreference('allow_add',1) == 1) {
    $this->smarty->assign('publisher_title', $this->GetPreference('publisher_title',''));
    $this->smarty->assign('contributor_title', $this->GetPreference('contributor_title',''));
    $this->smarty->assign('relation_title', $this->GetPreference('relation_title',''));
+   $this->smarty->assign('email_title', $this->GetPreference('email_title',''));
+   $this->smarty->assign('phone_title', $this->GetPreference('phone_title',''));
+   $this->smarty->assign('fax_title', $this->GetPreference('fax_title',''));
+   $this->smarty->assign('street_title', $this->GetPreference('street_title',''));
    $this->smarty->assign('location_title', $this->GetPreference('location_title',''));
    $this->smarty->assign('region_title', $this->GetPreference('region_title',''));
+   $this->smarty->assign('postcode_title', $this->GetPreference('postcode_title',''));
+   $this->smarty->assign('country_title', $this->GetPreference('country_title',''));
    $this->smarty->assign('latitude_title', $this->GetPreference('latitude_title',''));
    $this->smarty->assign('longitude_title', $this->GetPreference('longitude_title',''));
    $this->smarty->assign('ogtype_title', $this->GetPreference('ogtype_title',''));
    $this->smarty->assign('ogimage_title', $this->GetPreference('ogimage_title','0'));
    $this->smarty->assign('favicon_title', $this->GetPreference('favicon_title','0'));
-   $this->smarty->assign('favsize_title', $this->GetPreference('favsize_title','0'));
+   $this->smarty->assign('favsize_title', $this->GetPreference('favsize_title',''));
+   $this->smarty->assign('fbpage_title', $this->GetPreference('fbpage_title',''));
    $this->smarty->assign('fbadmin_title', $this->GetPreference('fbadmin_title',''));
    $this->smarty->assign('fbapp_title', $this->GetPreference('fbapp_title',''));
    $this->smarty->assign('analyticstype_title', $this->GetPreference('analyticstype_title','-1'));
