@@ -92,6 +92,9 @@ $smarty->assign('input_dublin_title', $this->CreateInputCheckbox($id,'dublin_tit
 $smarty->assign('title_opengraph_title',$this->Lang('opengraph_title'));
 $smarty->assign('input_opengraph_title', $this->CreateInputCheckbox($id,'opengraph_title','1', $this->GetPreference('opengraph_title','0')));
 
+$smarty->assign('title_tweetme_title',$this->Lang('tweetme_title'));
+$smarty->assign('input_tweetme_title', $this->CreateInputCheckbox($id,'tweetme_title','1', $this->GetPreference('tweetme_title','0')));
+
 $smarty->assign('title_touchicon_title',$this->Lang('touchicon_title'));
 $smarty->assign('input_touchicon_title',$this->CreateInputDropdown($id,'touchicon_title',$files_list,-1,$this->GetPreference('touchicon_title','')));
 
@@ -128,15 +131,33 @@ $smarty->assign('input_publisher_title',$this->CreateInputText($id,'publisher_ti
 $smarty->assign('title_contributor_title',$this->Lang('contributor_title'));
 $smarty->assign('input_contributor_title',$this->CreateInputText($id,'contributor_title',$this->GetPreference('contributor_title',''),50,255));
 
+$smarty->assign('title_email_title',$this->Lang('email_title'));
+$smarty->assign('input_email_title',$this->CreateInputText($id,'email_title',$this->GetPreference('email_title',''),50,255));
+
+$smarty->assign('title_phone_title',$this->Lang('phone_title'));
+$smarty->assign('input_phone_title',$this->CreateInputText($id,'phone_title',$this->GetPreference('phone_title',''),50,255));
+
+$smarty->assign('title_fax_title',$this->Lang('fax_title'));
+$smarty->assign('input_fax_title',$this->CreateInputText($id,'fax_title',$this->GetPreference('fax_title',''),50,255));
+
 $smarty->assign('title_relation_title',$this->Lang('relation_title'));
 $smarty->assign('input_relation_title',$this->CreateInputText($id,'relation_title',$this->GetPreference('relation_title',''),50,255));
 
+$smarty->assign('title_street_title',$this->Lang('street_title'));
+$smarty->assign('input_street_title',$this->CreateInputText($id,'street_title',$this->GetPreference('street_title',''),50,255));
+
 $smarty->assign('title_location_title',$this->Lang('location_title'));
 $smarty->assign('input_location_title',$this->CreateInputText($id,'location_title',$this->GetPreference('location_title',''),50,255));
 
 $smarty->assign('title_region_title',$this->Lang('region_title'));
 $smarty->assign('input_region_title',$this->CreateInputText($id,'region_title',$this->GetPreference('region_title',''),10,5));
 
+$smarty->assign('title_postcode_title',$this->Lang('postcode_title'));
+$smarty->assign('input_postcode_title',$this->CreateInputText($id,'postcode_title',$this->GetPreference('postcode_title',''),50,255));
+
+$smarty->assign('title_country_title',$this->Lang('country_title'));
+$smarty->assign('input_country_title',$this->CreateInputText($id,'country_title',$this->GetPreference('country_title',''),10,5));
+
 $smarty->assign('title_latitude_title',$this->Lang('latitude_title'));
 $smarty->assign('input_latitude_title',$this->CreateInputText($id,'latitude_title',$this->GetPreference('latitude_title',''),50,255));
 
@@ -155,6 +176,9 @@ $smarty->assign('input_favicon_title',$this->CreateInputDropdown($id,'favicon_ti
 $smarty->assign('title_favsize_title',$this->Lang('favsize_title'));
 $smarty->assign('input_favsize_title',$this->CreateInputText($id,'favsize_title',$this->GetPreference('favsize_title',''),50,255));
 
+$smarty->assign('title_fbpage_title',$this->Lang('fbpage_title'));
+$smarty->assign('input_fbpage_title',$this->CreateInputText($id,'fbpage_title',$this->GetPreference('fbpage_title',''),50,255));
+
 $smarty->assign('title_fbadmin_title',$this->Lang('fbadmin_title'));
 $smarty->assign('input_fbadmin_title',$this->CreateInputText($id,'fbadmin_title',$this->GetPreference('fbadmin_title',''),50,255));
 
